@@ -11,7 +11,7 @@ LEAN_CLASS_KEY = "__leanapi_class__"
 
 def controller(path: str, router: APIRouter, depend: Callable[..., None] = None) -> Callable[[Type[T]], Type[T]]:
     def decorator(cls: Type[T]) -> Type[T]:
-        return _controller(router, path, [Depends(depend)] if depend else None, cls)
+        return _controller(router, path, [Depends(depend)], cls)
 
     return decorator
 
