@@ -79,9 +79,6 @@ class ApiServer:
                 allow_methods=["*"],
                 allow_headers=["*"],
             )
-        print("*" * 25, " LEAN API from {developer::kitchen}", "*" * 25)
-        print(f"[PROJECT]: {self.settings.NAME}")
-        print(f"[VERSION]: {self.settings.VERSION}")
         self.app.include_router(router)
         return self
 
@@ -92,7 +89,7 @@ class ApiServer:
         """
         self.host = host
         self.port = port
-        print(f"[HOST]: http://{self.host}:{self.port}")
-        print(f"[SWAGGER]: http://{self.host}:{self.port}/{self.settings.BASE_URL.lstrip('/')}/docs")
+        print(f"[Host]: http://{self.host}:{self.port}")
+        print(f"[Swagger]: http://{self.host}:{self.port}/{self.settings.BASE_URL.lstrip('/').rstrip('/')}/docs")
         print("*" * 87)
         uvicorn.run(self.app, host=self.host, port=self.port)
